#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os

ROOT_DIR = os.path.realpath(os.path.join(os.path.dirname(__file__), '..'))

# List of languages to read from and write po file to
LANGUAGES = ['en', 'pl', 'jp']

# GDocs authentication information
EMAIL = 'ttestt123321@gmail.com'
PASSWORD = 'zxcasdqwe.'
URL = 'https://docs.google.com/spreadsheet/ccc?key=0AnVOHClWGpLZdFdNVVJJLUZkbkh1bGFOWUZqRnYxbGc#gid=0'

# Header which will be attached on top of every po file
HEADER = '# translated with c3po\n'

# Path to locale folder with language directories
LOCALE_ROOT = os.path.join(ROOT_DIR, 'conf', 'locale')
# Path from lang folder to po file
PO_FILES_PATH = 'LC_MESSAGES'
# Temporary directory where csv file and temp lines.txt will be saved
TEMP_PATH = os.path.join(ROOT_DIR, 'temp')

# Git information
GIT_REPOSITORY = 'git@git.hiddendata.co:mnogacki/testpo.git'
GIT_BRANCH = 'master'
GIT_MESSAGE = 'Message'

# Source to identify user later on GDocs
SOURCE = 'PO Translator'

METADATA = {
    'MIME-Version': '1.0',
    'Content-Type': 'text/plain; charset=UTF-8',
    'Content-Transfer-Encoding': '8bit',
}

# ODS Formatting
ODD_COLUMN_BG_COLOR = '#FFFFFF'
EVEN_COLUMN_BG_COLOR = '#F9F9F9'
TITLE_ROW_BG_COLOR = '#D9EDF7'
TITLE_ROW_FONT_COLOR = '#3A87AD'
MSGSTR_COLUMN_WIDTH = '2.5in'
NOTES_COLUMN_WIDTH = '1.5in'



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from mod import initializer
from mod import communicator
from mod.communicator import git_push, git_checkout
from mod.initializer import ALLOWED_COMMANDS


def main():
    command = initializer.initialize()

    if command[0] == 'push':
        git_push(command[1])
    elif command[0] == 'checkout':
        git_checkout()
    elif command[0] in ALLOWED_COMMANDS:
        com = communicator.Communicator()
        getattr(com, command[0])()


if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys
import os

import settings_default


class Singleton(type):
    def __init__(cls, name, bases, sdict):
        super(Singleton, cls).__init__(name, bases, sdict)
        cls.instance = None

    def __call__(cls, *args, **kwargs):
        if cls.instance is None:
            cls.instance = super(Singleton, cls).__call__(*args, **kwargs)
        return cls.instance


class SettingsWrapper(object):
    __metaclass__ = Singleton

    settings_dict = {}
    custom_dict = {}

    def __init__(self):
        super(SettingsWrapper, self).__init__()
        self.settings_dict = self.module_to_dict(settings_default)
        self.configure()

    def dict_to_attrs(self, sdict):
        for k, v in sdict.items():
            setattr(self, k, v)

    def configure(self):
        sdict = self.settings_dict
        sdict.update(self.custom_dict)
        self.dict_to_attrs(sdict)

    @classmethod
    def module_to_dict(cls, module):
        cdict = {}
        for attr in dir(module):
            if attr.startswith('_'):
                continue
            cdict[attr] = getattr(module, attr)
        return cdict

    def set_config(self, custom_settings_path, params):
        cs_path, cs_name = os.path.split(custom_settings_path)
        if cs_name.endswith('.py'):
            cs_name = cs_name[:-3]
        sys.path.insert(0, cs_path)
        custom_settings = __import__(cs_name)
        sys.path = sys.path[1:]
        self.custom_dict = self.module_to_dict(custom_settings)
        self.custom_dict.update(params)
        self.configure()

    def print_settings(self):
        for attr in dir(self):
            if not attr.startswith('_'):
                print attr, getattr(self, attr)


settings = SettingsWrapper()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import csv
import os
import shutil
import unittest

import gdata.data
from c3po.converters.po_ods import csv_to_ods

from mod.communicator import Communicator


TESTS_URL = 'https://docs.google.com/spreadsheet/ccc?key=0AnVOHClWGpLZdGFpQmpVUUx2eUg4Z0NVMGVQX3NrNkE#gid=0'


PO_CONTENT_LOCAL = [r'''# test
msgid ""
msgstr ""
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=UTF-8\n"
"Content-Transfer-Encoding: 8bit\n"
"Language: %s\n"

#: tpl/base_site.html:44
msgid "Translation1"
msgstr "Str1 local"

#: tpl/base_site.html:44
msgid "Translation2"
msgstr ""

''', r'''# test
msgid ""
msgstr ""
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=UTF-8\n"
"Content-Transfer-Encoding: 8bit\n"
"Language: %s\n"

#: tpl/base_site.html:44
msgid "Custom1"
msgstr "Str1 local"

#: tpl/base_site.html:44
msgid "Custom2"
msgstr ""

''']

CSV_TRANS_GDOCS = [
    ['comment', 'msgid', 'en:msgstr', 'pl:msgstr', 'jp:msgstr'],
    ['', 'Translation1', 'Str1 gdocs', 'Str1 gdocs', 'Str1 gdocs'],
    ['', 'Translation3', 'Str3', 'Str3', 'Str3'],
    ['', 'Custom1', 'Str1 gdocs', 'Str1 gdocs', 'Str1 gdocs'],
    ['', 'Custom3', 'Str3', 'Str3', 'Str3'],
]

CSV_META_GDOCS = [
    ['file', 'metadata'],
    ['custom.po', "{'occurrences': [(u'tpl/base_site.html', u'44')]}"],
    ['custom.po', "{'occurrences': [(u'tpl/base_site.html', u'44')]}"],
    ['django.po', "{'occurrences': [(u'tpl/base_site.html', u'44')]}"],
    ['django.po', "{'occurrences': [(u'tpl/base_site.html', u'44')]}"],
]

PO_CONTENT_MERGED = [r'''# test
msgid ""
msgstr ""
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=UTF-8\n"
"Content-Transfer-Encoding: 8bit\n"
"Language: %s\n"

#: tpl/base_site.html:44
msgid "Translation1"
msgstr "Str1 gdocs"

#: tpl/base_site.html:44
msgid "Translation3"
msgstr "Str3"

#: tpl/base_site.html:44
msgid "Translation2"
msgstr ""
''', r'''# test
msgid ""
msgstr ""
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=UTF-8\n"
"Content-Transfer-Encoding: 8bit\n"
"Language: %s\n"

#: tpl/base_site.html:44
msgid "Custom1"
msgstr "Str1 gdocs"

#: tpl/base_site.html:44
msgid "Custom3"
msgstr "Str3"

#: tpl/base_site.html:44
msgid "Custom2"
msgstr ""
''']


class TestCommunicator(unittest.TestCase):

    def setUp(self):
        self.temp_dir = 'temp-conf'
        if os.path.exists(self.temp_dir):
            shutil.rmtree(self.temp_dir)
        self.languages = ['en', 'pl', 'jp']
        self.po_filenames = ['custom.po', 'django.po']
        self.locale_root = os.path.join(self.temp_dir, 'locale')
        self.po_files_path = 'LC_MESSAGES'
        self.header = '# test\n'
        os.makedirs(self.locale_root)
        for lang in self.languages:
            lang_path = os.path.join(self.locale_root, lang, self.po_files_path)
            os.makedirs(lang_path)

            with open(os.path.join(lang_path, self.po_filenames[0]), 'wb') as po_file:
                po_file.write(PO_CONTENT_LOCAL[0] % lang)
            with open(os.path.join(lang_path, self.po_filenames[1]), 'wb') as po_file:
                po_file.write(PO_CONTENT_LOCAL[1] % lang)

        self.com = Communicator(url=TESTS_URL, languages=self.languages, locale_root=self.locale_root,
                                po_files_path=self.po_files_path, header=self.header)
        self.com.clear()

    def tearDown(self):
        shutil.rmtree(self.temp_dir)
        self.com.clear()

    def test_multiple_files_sync(self):
        temp_trans_path = os.path.join(self.temp_dir, 'temp_trans.csv')
        temp_meta_path = os.path.join(self.temp_dir, 'temp_meta.csv')
        temp_ods_path = os.path.join(self.temp_dir, 'temp.ods')
        with open(temp_trans_path, 'wb') as csv_file:
            writer = csv.writer(csv_file)
            writer.writerows(CSV_TRANS_GDOCS)
        with open(temp_meta_path, 'wb') as csv_file:
            writer = csv.writer(csv_file)
            writer.writerows(CSV_META_GDOCS)

        csv_to_ods(temp_trans_path, temp_meta_path, temp_ods_path)

        entry = self.com.gd_client.GetResourceById(self.com.key)
        media = gdata.data.MediaSource(file_path=temp_ods_path,
                                       content_type='application/x-vnd.oasis.opendocument.spreadsheet')
        self.com.gd_client.UpdateResource(entry, media=media, update_metadata=False)

        self.com.synchronize()

        for lang in self.languages:
            lang_path = os.path.join(self.locale_root, lang, self.po_files_path)

            with open(os.path.join(lang_path, self.po_filenames[0]), 'rb') as po_file:
                self.assertEqual(po_file.read(), PO_CONTENT_MERGED[0] % lang)

            with open(os.path.join(lang_path, self.po_filenames[1]), 'rb') as po_file:
                self.assertEqual(po_file.read(), PO_CONTENT_MERGED[1] % lang)


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import ast
import shutil
import os
from itertools import izip

import polib

from c3po.conf import settings
from c3po.converters.unicode import UnicodeWriter, UnicodeReader


def _get_all_po_filenames(locale_root, lang, po_files_path):
    """
    Get all po filenames from locale folder and return list of them.
    Assumes a dictionary structure <locale_root>/<lang>/<po_files_path>/<filename>.
    """
    all_files = os.listdir(os.path.join(locale_root, lang, po_files_path))
    return filter(lambda s: s.endswith('.po'), all_files)


def _get_new_csv_writers(trans_title, meta_title, trans_csv_path, meta_csv_path):
    """
    Prepare new csv writers, write title rows and return them.
    """
    trans_writer = UnicodeWriter(trans_csv_path)
    trans_writer.writerow(trans_title)

    meta_writer = UnicodeWriter(meta_csv_path)
    meta_writer.writerow(meta_title)

    return trans_writer, meta_writer


def _prepare_locale_dirs(languages, locale_root):
    """
    Prepare locale dirs for writing po files. Create new directories if they doesn't exist.
    """
    trans_languages = []
    for i, t in enumerate(languages):
        lang = t.split(':')[0]
        trans_languages.append(lang)
        lang_path = os.path.join(locale_root, lang)
        if not os.path.exists(lang_path):
            os.makedirs(lang_path)
    return trans_languages


def _prepare_polib_files(files_dict, filename, languages, locale_root, po_files_path, header):
    """
    Prepare polib file object for writing/reading from them. Create directories and write header if needed.
    For each language, ensure there's a translation file named "filename" in the correct place.
    Assumes (and creates) a dictionary structure <locale_root>/<lang>/<po_files_path>/<filename>.
    """
    files_dict[filename] = {}
    for lang in languages:
        file_path = os.path.join(locale_root, lang, po_files_path)
        if not os.path.exists(file_path):
            os.makedirs(file_path)

        if header is not None:
            _write_header(os.path.join(file_path, filename), lang, header)

        files_dict[filename][lang] = polib.pofile(os.path.join(file_path, filename), encoding="UTF-8")


def _write_entries(po_files, languages, msgid, msgstrs, metadata, comment):
    """
    Write msgstr for every language with all needed metadata and comment.
    Metadata are parser from string into dict, so read them only from gdocs.
    """
    for i, lang in enumerate(languages):
        meta = ast.literal_eval(metadata)
        entry = polib.POEntry(**meta)
        entry.tcomment = comment
        entry.msgid = msgid
        entry.msgstr = unicode(msgstrs[i])
        po_files[lang].append(entry)
        po_files[lang].save()


def _write_header(po_path, lang, header):
    """
    Write header into po file for specific lang. Metadata are read from settings file.
    """
    po_file = open(po_path, 'w')
    po_file.write(header + '\n')
    po_file.write('msgid ""' +
                  '\nmsgstr ""' +
                  '\n"MIME-Version: ' + settings.METADATA['MIME-Version'] + r'\n"'
                  '\n"Content-Type: ' + settings.METADATA['Content-Type'] + r'\n"'
                  '\n"Content-Transfer-Encoding: ' + settings.METADATA['Content-Transfer-Encoding'] + r'\n"'
                  '\n"Language: ' + lang + r'\n"' + '\n')
    po_file.close()


def _write_new_messages(po_file_path, trans_writer, meta_writer, msgids, languages_num):
    """
    Write new msgids which appeared in po files with empty msgstrs values and metadata.
    Look for all new msgids which are diffed with msgids list provided as an argument.
    """
    po_filename = os.path.basename(po_file_path)
    po_file = polib.pofile(po_file_path)

    new_trans = 0
    for entry in po_file:
        if entry.msgid.rstrip() not in msgids:
            new_trans += 1
            trans = [entry.tcomment, entry.msgid, entry.msgstr]
            trans += [''] * languages_num

            meta = dict(entry.__dict__)
            meta.pop('msgid', None)
            meta.pop('msgstr', None)
            meta.pop('tcomment', None)

            trans_writer.writerow(trans)
            meta_writer.writerow([po_filename, str(meta)])

    return new_trans


def po_to_csv_merge(languages, locale_root, po_files_path,
                    local_trans_csv, local_meta_csv, gdocs_trans_csv, gdocs_meta_csv):
    """
    Converts po file to csv GDocs spreadsheet readable format. Merges them if some msgid aren't in the spreadsheet.
    :param languages: list of language codes
    :param locale_root: path to locale root folder containing directories with languages
    :param po_files_path: path from lang directory to po file
    :param local_trans_csv: path where local csv with translations will be created
    :param local_meta_csv: path where local csv with metadata will be created
    :param gdocs_trans_csv: path to gdoc csv with translations
    """
    msgids = []

    trans_reader = UnicodeReader(gdocs_trans_csv)
    meta_reader = UnicodeReader(gdocs_meta_csv)

    try:
        trans_title = trans_reader.next()
        meta_title = meta_reader.next()
    except StopIteration:
        trans_title = ['comment', 'msgid']
        trans_title += map(lambda s: s + ':msgstr', languages)
        meta_title = ['file', 'metadata']

    trans_writer, meta_writer = _get_new_csv_writers(trans_title, meta_title, local_trans_csv, local_meta_csv)

    for trans_row, meta_row in izip(trans_reader, meta_reader):
        msgids.append(trans_row[1].rstrip())
        trans_writer.writerow(trans_row)
        meta_writer.writerow(meta_row)

    trans_reader.close()
    meta_reader.close()

    po_files = _get_all_po_filenames(locale_root, languages[0], po_files_path)

    new_trans = False
    for po_filename in po_files:
        po_file_path = os.path.join(locale_root, languages[0], po_files_path, po_filename)
        ret = _write_new_messages(po_file_path, trans_writer, meta_writer, msgids, len(languages)-1)
        if ret > 0:
            new_trans = True

    trans_writer.close()
    meta_writer.close()

    return new_trans


def csv_to_po(trans_csv_path, meta_csv_path, locale_root, po_files_path, header=None):
    """
    Converts GDocs spreadsheet generated csv file into po file.
    :param trans_csv_path: path to temporary file with translations
    :param meta_csv_path: path to temporary file with meta information
    :param locale_root: path to locale root folder containing directories with languages
    :param po_files_path: path from lang directory to po file
    """
    shutil.rmtree(locale_root)

    # read title row and prepare descriptors for po files in each lang
    trans_reader = UnicodeReader(trans_csv_path)
    meta_reader = UnicodeReader(meta_csv_path)
    try:
        title_row = trans_reader.next()
    except StopIteration:
        # empty file
        return

    trans_languages = _prepare_locale_dirs(title_row[2:], locale_root)

    po_files = {}

    meta_reader.next()
    # go through every row in downloaded csv file
    for trans_row, meta_row in izip(trans_reader, meta_reader):
        filename = meta_row[0].rstrip()
        metadata = meta_row[1].rstrip()
        comment = trans_row[0].rstrip()
        msgid = trans_row[1].rstrip()

        if filename not in po_files:
            _prepare_polib_files(po_files, filename, trans_languages, locale_root, po_files_path, header)

        _write_entries(po_files[filename], trans_languages, msgid, trans_row[2:], metadata, comment)

    trans_reader.close()
    meta_reader.close()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
from itertools import izip

import polib
from odslib import ODS
from c3po.conf import settings
from c3po.converters.po_csv import _get_all_po_filenames
from c3po.converters.unicode import UnicodeReader


def _prepare_ods_columns(ods, trans_title_row):
    """
    Prepare columns in new ods file, create new sheet for metadata, set columns color and width.
    Set formatting style info in your settings.py file in ~/.c3po/ folder.
    """
    ods.content.getSheet(0).setSheetName('Translations')
    ods.content.makeSheet('Meta options')
    ods.content.getColumn(0).setWidth('1.5in')
    ods.content.getColumn(1).setWidth('5.0in')
    ods.content.getCell(0, 0).stringValue('file').setCellColor(settings.TITLE_ROW_BG_COLOR) \
                                                 .setBold(True).setFontColor(settings.TITLE_ROW_FONT_COLOR)
    ods.content.getCell(1, 0).stringValue('metadata').setCellColor(settings.TITLE_ROW_BG_COLOR) \
                                                     .setBold(True).setFontColor(settings.TITLE_ROW_FONT_COLOR)

    ods.content.getSheet(0)
    for i, title in enumerate(trans_title_row):
        ods.content.getColumn(i).setWidth(settings.MSGSTR_COLUMN_WIDTH)
        ods.content.getCell(i, 0).stringValue(title).setCellColor(settings.TITLE_ROW_BG_COLOR) \
                                                    .setBold(True).setFontColor(settings.TITLE_ROW_FONT_COLOR)
    ods.content.getColumn(0).setWidth(settings.NOTES_COLUMN_WIDTH)


def _write_trans_into_ods(ods, languages, locale_root, po_files_path, po_filename, start_row):
    """
    Write translations from po files into ods one file.
    Assumes a dictionary structure <locale_root>/<lang>/<po_files_path>/<filename>.
    """
    ods.content.getSheet(0)
    for i, lang in enumerate(languages[1:]):
        lang_po_path = os.path.join(locale_root, lang, po_files_path, po_filename)
        if os.path.exists(lang_po_path):
            po_file = polib.pofile(lang_po_path)
            for j, entry in enumerate(po_file):
                # start from 3 column, 1 row
                row = j+start_row
                ods.content.getCell(i+3, row).stringValue(entry.msgstr)
                if i % 2 == 1:
                    ods.content.getCell(i+3, row).setCellColor(settings.ODD_COLUMN_BG_COLOR)
                else:
                    ods.content.getCell(i+3, row).setCellColor(settings.EVEN_COLUMN_BG_COLOR)


def _write_row_into_ods(ods, sheet_no, row_no, row):
    """
    Write row with translations to ods file into specified sheet and row_no.
    """
    ods.content.getSheet(sheet_no)
    for j, col in enumerate(row):
        cell = ods.content.getCell(j, row_no+1)
        cell.stringValue(col)
        if j % 2 == 1:
            cell.setCellColor(settings.EVEN_COLUMN_BG_COLOR)
        else:
            cell.setCellColor(settings.ODD_COLUMN_BG_COLOR)


def po_to_ods(languages, locale_root, po_files_path, temp_file_path):
    """
    Converts po file to csv GDocs spreadsheet readable format.
    :param languages: list of language codes
    :param locale_root: path to locale root folder containing directories with languages
    :param po_files_path: path from lang directory to po file
    :param temp_file_path: path where temporary files will be saved
    """
    title_row = ['comment', 'msgid']
    title_row += map(lambda s: s + ':msgstr', languages)

    ods = ODS()

    _prepare_ods_columns(ods, title_row)

    po_files = _get_all_po_filenames(locale_root, languages[0], po_files_path)

    i = 1
    for po_filename in po_files:
        po_file_path = os.path.join(locale_root, languages[0], po_files_path, po_filename)

        start_row = i

        po = polib.pofile(po_file_path)
        for entry in po:
            meta = dict(entry.__dict__)
            meta.pop('msgid', None)
            meta.pop('msgstr', None)
            meta.pop('tcomment', None)

            ods.content.getSheet(1)
            ods.content.getCell(0, i).stringValue(po_filename).setCellColor(settings.ODD_COLUMN_BG_COLOR)
            ods.content.getCell(1, i).stringValue(str(meta)).setCellColor(settings.EVEN_COLUMN_BG_COLOR)

            ods.content.getSheet(0)
            ods.content.getCell(0, i).stringValue(entry.tcomment).setCellColor(settings.ODD_COLUMN_BG_COLOR)
            ods.content.getCell(1, i).stringValue("'" + entry.msgid).setCellColor(settings.EVEN_COLUMN_BG_COLOR)
            ods.content.getCell(2, i).stringValue(entry.msgstr).setCellColor(settings.ODD_COLUMN_BG_COLOR)

            i += 1

        _write_trans_into_ods(ods, languages, locale_root, po_files_path, po_filename, start_row)

    ods.save(temp_file_path)


def csv_to_ods(trans_csv, meta_csv, local_ods):
    """
    Converts csv files to one ods file
    :param trans_csv: path to csv file with translations
    :param meta_csv: path to csv file with metadata
    :param local_ods: path to new ods file
    """
    trans_reader = UnicodeReader(trans_csv)
    meta_reader = UnicodeReader(meta_csv)

    ods = ODS()

    trans_title = trans_reader.next()
    meta_reader.next()

    _prepare_ods_columns(ods, trans_title)

    for i, (trans_row, meta_row) in enumerate(izip(trans_reader, meta_reader)):
        _write_row_into_ods(ods, 0, i, trans_row)
        _write_row_into_ods(ods, 1, i, meta_row)

    trans_reader.close()
    meta_reader.close()

    ods.save(local_ods)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import getopt
import os
import shutil
import sys

from c3po.conf import settings


ALLOWED_COMMANDS = ('synchronize', 'download', 'upload', 'clear', 'checkout', 'push')


def usage():
    print('Usage: ./c3po.py <command> <options>\n\n'
          'Commands are:\n'
          'synchronize\tdownloads GDocs and synchronizes it\'s content with local po files\n'
          'download\tdownloads GDoc and converts it to po files\n'
          'upload\t\tuploads local po files to GDocs overwriting it\n'
          'clear\t\tclears GDoc file\n'
          'push\t\tpush project into git repository\n'
          'checkout\tcheckout git project\n\n'
          'Options are:\n'
          '-e <email>, --email=<email>\tGoogle Docs email address\n'
          '-p <pass>, --password=<pass>\tGoogle Docs password\n'
          '-u <url>, --url=<url>\t\tSpreadsheet URL\n'
          '-l <dir>, --locale=<dir>\tLocale directory path\n'
          '-P <dir>, --po-path=<dir>\tPath from concrete lang dir to .po file\n'
          '-m <msg>, --message=<msg>\tSpecify git message\n'
          '-h, --help\t\t\tShow this help message\n')


def _get_command(params_command):
    if params_command in ALLOWED_COMMANDS:
        command = params_command
    else:
        usage()
        sys.exit()
    return command


def _get_params_from_options(opts):
    params = {}
    for option, param in opts:
        if option in ('-h', '--help'):
            usage()
            sys.exit()
        elif option in ('-e', '--email'):
            params['EMAIL'] = param
        elif option in ('-p', '--password'):
            params['PASSWORD'] = param
        elif option in ('-u', '--url'):
            params['URL'] = param
        elif option in ('-l', '--locale'):
            params['LOCALE_ROOT'] = param
        elif option in ('-P', '--po-path'):
            params['PO_FILES_PATH'] = param
        elif option in ('-s', '--settings'):
            params['SETTINGS'] = param
        elif option in ('-m', '--message'):
            params['GIT_MESSAGE'] = param
        else:
            usage()
            sys.exit()
    return params


def _set_settings_file(settings, params):
    if 'SETTINGS' in params:
        settings.set_config(params['SETTINGS'], params)
    else:
        user_settings_path = os.path.expanduser('~/.c3po/settings.py')
        if os.path.exists(user_settings_path):
            settings.set_config(user_settings_path, params)
        else:
            if not os.path.isdir(os.path.dirname(user_settings_path)):
                os.makedirs(os.path.dirname(user_settings_path))
            shutil.copy(os.path.join(os.path.dirname(__file__), '..', 'conf', 'settings_default.py'),
                        user_settings_path)
            settings.set_config(user_settings_path, params)

    return settings


def initialize():
    """
    Function to initialize settings from command line and/or custom settings file
    :return: Returns str with operation type
    """
    if len(sys.argv) == 1:
        usage()
        sys.exit()

    command = _get_command(sys.argv[1])

    try:
        opts, args = getopt.getopt(sys.argv[2:], 'h:e:p:u:l:P:s:m:',
                                   ['help', 'email=', 'password=', 'url=', 'locale=',
                                    'po-path=', 'settings=', 'message='])
    except getopt.GetoptError:
        usage()
        sys.exit()

    params = _get_params_from_options(opts)
    _set_settings_file(settings, params)

    if command == 'push':
        if 'GIT_MESSAGE' in params:
            return 'push', params['GIT_MESSAGE']
        return 'push', None

    return command, None



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

setup(
    name='C3PO',
    version='0.1.5',
    packages=['c3po', 'c3po.conf', 'c3po.mod', 'c3po.converters'],
    url='https://github.com/VorskiImagineering/C3PO',
    license='MIT',
    author=u'Marek Nogacki',
    author_email='m.nogacki@hiddendata.co',
    description='''C3PO is Python module responsible for converting all .po files from locale directory into one .ods
file and sending it to the Google Docs (spreadsheet link provided by user), so users with access to that spreadsheet
can translate expression included there.\n
This module provides Communicator which deals with uploading, downloading these translations and synchronizing whole
content by merging it. Package contains basic methods for converting po files into csv, ods formats and back. It also
provides methods for git push and git checkout po files into repository.''',
    install_requires=['gdata==2.0.18', 'polib==1.0.3', 'odslib==1.0.1'],
    entry_points={
        'console_scripts': [
            'c3po = c3po.c3po_cmd:main'
        ]
    },
    download_url='https://github.com/VorskiImagineering/C3PO/tarball/master',
)
